==> Glossary-0.6.7.tar.gz: Glossary/lang/ext/nb_NO.php <==
<?php
$lang['areyousure_altercontent'] = 'Er du sikker p&aring; at du vil utf&oslash;re denne handlingen?  &Aring; fortsette vil permanent endre ditt innhold';
$lang['filter_site_now'] = 'Filtrer n&aring;';
$lang['friendlyname'] = 'Ordliste / Ordbok';
$lang['postinstall'] = '<p>Husk &aring; sette &quot;Modify Glossary&quot; tillatelser for &aring; bruke denne modulen!</p>
<p>Du vil sikkert ogs&aring; g&aring; inn og endre verdier ogs&aring;. Jeg har satt spesielle verdier for &aring; demonstrere muligheter. Men du vil f.eks. sikkert &oslash;nske mer enn fem uttrykk p&aring; en side,
og du vil &oslash;nske &aring; slette mine eksempel uttrykk og kategorier.';
$lang['postuninstall'] = 'Ble fjernet.';
$lang['uninstalled'] = 'Modul avinstallert.';
$lang['installed'] = 'Modul versjon %s installert.';
$lang['prefsupdated'] = 'Modul innstillinger oppdatert.';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk dine rettigheter.';
$lang['error'] = 'Feil!';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['title_mod_prefs'] = 'Modul innstillinger';
$lang['title_mod_admin'] = 'Modul administrasjonspanel';
$lang['title_term'] = 'Uttrykk';
$lang['title_definition'] = 'Definisjon';
$lang['column_definition'] = 'Definisjon';
$lang['title_default_template'] = 'Standard visnings mal';
$lang['title_default_single_term_template'] = 'Standard visnings mal for sprettopp vindu';
$lang['title_filter_site'] = 'Filtrer nettsted for uttrykk?';
$lang['title_filter_news'] = 'Filtrer Nyhetersartikler for uttrykk?';
$lang['title_number_show'] = 'Antall uttrykk &aring; vise pr side';
$lang['title_default_number_show'] = 'Standard antall uttrykk &aring; vise pr side';
$lang['title_filter_site_label'] = 'Aktiver alle uttrykk p&aring; nettstedet? (advarsel - bremser nettstedet)';
$lang['title_glossary_page'] = 'Ordliste side (m&aring;l for aktive lenker)';
$lang['title_disable_prettyurls'] = 'Koble ut vakre nettadresser for denne modulen';
$lang['title_disable_prettyurls_label'] = 'Koble ut';
$lang['title_glossary_inline'] = 'Vise linkede uttrykk inline?';
$lang['title_show_termids'] = 'Vis Uttrykk ID-nummere i admin';
$lang['title_display_tab'] = 'Ordliste visningsvalg';
$lang['title_single_term'] = 'Vise linkede uttrykk p&aring; egen side?';
$lang['title_single_term_label'] = 'Vise enkle uttrykk (i motsetning til full ordbok)';
$lang['title_wysiwyg_definitions'] = 'Benytt WYSIWYG for &aring; skrive uttrykksdefinisjoner?';
$lang['title_wysiwyg_terms'] = 'Benytt WYSIWYG for &aring; skrive uttrykk?';
$lang['title_wysiwyg_terms_help'] = 'Vennligst v&aelig;r oppmerksom p&aring; at markup inne i utrykk kan p&aring;virke bokstavinndeling(aphabetizing) og med aktiverte uttrykk!';
$lang['title_link_tab'] = 'Ordbok Link valg';
$lang['title_admin_tab'] = 'Administrasjonspanel valg';
$lang['title_filtering_tab'] = 'Nettsted Uttrykk-filtreringsvalg';
$lang['title_number_spining_chars'] = 'Maksimum antall bokstaver &aring; bruke av et uttrykk i Ordbok lenken';
$lang['title_process_smarty'] = 'Prosesser Smartytagger i definisjoner?';
$lang['filter_link'] = 'Link til Ordbok siden';
$lang['column_term'] = 'Uttrykk';
$lang['column_termid'] = 'Uttrykk ID';
$lang['column_action'] = 'Handling';
$lang['column_category'] = 'Kategori';
$lang['title_admin_panel'] = 'Ordliste / Ordbok / (FAQ)';
$lang['title_term_list'] = 'Uttrykk';
$lang['title_name'] = 'Navn';
$lang['title_cats'] = 'Kategorier';
$lang['title_filter_category'] = 'Vis kun denne kategorien:';
$lang['title_all'] = 'Alle kategorier';
$lang['column_template'] = 'Mal navn';
$lang['title_template'] = 'Mal definisjon';
$lang['addterm'] = 'Legg til nytt Uttrykk';
$lang['termadded'] = 'Uttrykk ble lagt til.';
$lang['termdeleted'] = 'Uttrykk ble slettet.';
$lang['edit'] = 'Rediger uttrykk';
$lang['no'] = 'Nei';
$lang['yes'] = 'Ja';
$lang['filter'] = 'Filtrer';
$lang['delete'] = 'Slett uttrykk';
$lang['suredelete'] = 'Er du sikker p&aring; at du vil slette uttrykket %s?';
$lang['listterms'] = 'Behandle uttrykk';
$lang['listtempl'] = 'Behandle maler';
$lang['listcats'] = 'Behandle kategorier';
$lang['addcat'] = 'Legg til kategori';
$lang['editcat'] = 'Rediger kategori';
$lang['delcat'] = 'Slett kategori';
$lang['manageprefs'] = 'Admin innstillinger';
$lang['templatelist'] = 'Maler';
$lang['unknown_term'] = 'Ukjent uttrykk %s forespurt.';
$lang['glossary_page_help'] = 'Velg en side her som inneholder en tagg for &aring; vise ordbok informasjonen, f.eks., en side som inneholder {cms_module module=&quot;Glossary&quot;}';
$lang['glossary_prettyurls_help'] = '&Aring; koble ut vakre nettadresser for denne modulen kan hjelpe i tilfeller hvor noen av s&oslash;keuttrykkene har ikke-alfanummeriske tegn eller mellomrom.';
$lang['glossary_inline_help'] = 'Bruk f&oslash;lgende valg om du &oslash;nsker at dine aktive-uttrykk definisjoner skal vises in-line. Dette er gjensidig eksklusivt for linking til Ordbok siden.';
$lang['title_glossary_inline_label'] = 'Vis inline';
$lang['notemplates'] = 'Ingen maler i databasen.';
$lang['nocats'] = 'Ingen kategorier i databasen.';
$lang['addtemplate'] = 'Legg til mal';
$lang['templateupdated'] = 'Mal oppdatert';
$lang['templatedeleted'] = 'Mal slettet';
$lang['catupdated'] = 'Kategori oppdatert';
$lang['catdeleted'] = 'Kategori slettet';
$lang['areyousure'] = 'Er du sikker p&aring; du vil slette %s?';
$lang['next'] = ' : Neste &raquo;';
$lang['prev'] = '&laquo; Forrige : ';
$lang['moddescription'] = 'Denne modulen tillater deg &aring; lage en liste med uttrykk og definisjoner &aring; vise frem. Et uttrykk kan v&aelig;re et ord, et ofte spurt sp&oslash;rsm&aring;l eller noe lignende.';
$lang['changelog'] = '<ul>
<li>Version 0.6.6,  January 2009. Bug fixes, code refactoring, added &quot;random&quot; action, option to allow smarty tags in definitions, options for WYSIWYG.</li>
<li>Version 0.6.5,  January 2009. Bug fixes, now allows teplate specification to be name or id.</li>
<li>Version 0.6.4,  September 2008.  Adds glossary terms to the searchable content.  Bump minimum cms version to 1.4.1</li>
<li>Version 0.6.3,  March 2008.  Adds the ability to disable pretty urls for this module.  Bump minimum cms version to 1.2</li>
<li>Version 0.6.2.  December 2007.  Fixes a bug in preferences related to inline/non inline, bumps minimum cms version, Adds the RegisterModulePlugin call.</li>
<li>Version 0.6.1.  November 2007.  Adds functionality so that content never returns empty</li>
<li>Version 0.6. November 2007.  Adds a button to filter content and news on demand, splits it out into multiple files for reduced memory footprint.</li>
<li>Version 0.5.1. 28 Mar 2007.  Urls now validate. There ya go, Mr. InSiPiD.</li>
<li>Version 0.5. 8 November 2006. Removed pop-up window links, added inline display, and category filtering / requested features for InSiPiD.</li>
<li>Version 0.4. 7 November 2006. Updated for CMS MS 1.0.x, added features for InSiPiD.</li>
<li>Version 0.3. 24 October 2005. Bug fixes, new default template, more Admin configuration options.</li>
<li>Version 0.2. 20 October 2005. Initial Public Release.</li></ul>';
$lang['help_glossary_single'] = 'Vis et uttrykk';
$lang['help_glossary_tid'] = 'Term ID (UttrykksID) &aring; utheve/fremheve';
$lang['help_glossary_catid'] = 'Begrens listen til uttrykk i kategori ID &quot;catid&quot;';
$lang['help_glossary_start'] = 'Innrykk i liste for &aring; starte listing av uttrykk';
$lang['help_glossary_term'] = 'Uttrykk &aring; utheve/fremheve';
$lang['help_glossary_cat'] = 'Begrens listen til uttrykk i kategorien &quot;cat&quot;';
$lang['help_glossary_template'] = 'Malnavn eller ID &aring; benytte for &aring; formatere uttrykk';
$lang['help_glossary_term_count'] = 'Antall uttrykk som skal vises p&aring; en side (overstyrer standardinnstilling i admin)';
$lang['help_glossary_show_nav'] = 'Sett til 0 for &aring; skjule sideinndelings menyen';
$lang['help_glossary_keyword'] = 'Begrens til de uttrykk hvor definisjonen inneholder &quot;keyword&quot;';
$lang['help_glossary_sort'] = 'Sorteringsrekkef&oslash;lge: n&aring; st&oslash;ttes kun &quot;alpha&quot; eller &quot;random&quot;';
$lang['help_glossary_no_pass_restrictions'] = 'For &aring; vise en filtrert eller p&aring; annen m&aring;te begrenset liste, men &aring; f&aring;r &aring; ikke ha den utvidede listen begrenset, list feltene her (se eksemplet ovenfor)';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This allows the administrator to create a list of terms, which will appear on a page. Clicking on the term will expand it to include the definition.</p>
<h3>How Do I Use It</h3>
<h4>Standard Glossary Page</h4>
<p>Install it by placing the module in a page or template using the smarty tag &amp;#123;cms_module module=&#039;Glossary&#039;}</p>
<p>You can have it start with a term expanded by passing a term=Term parameter, or passing a tid=term_id.</p>
<p>You can limit it to a specific category by passing a cat=&quot;Category&quot; parameter.</p>
<p>You can override the default template by passing a template=&quot;template_id&quot; parameter (use the numeric
id for the template, or the template name).</p>
<p>You can limit it to definitions containing a keyword by passing a keyword=&quot;keyword&quot;.</p>
<p>This module also will read the URL, and support specifications of &quot;term&quot; or &quot;cat&quot; on the URL. So, for example, you could have an URL like http://mysite/index.php?page=10&amp;amp;term=myterm. If page 10 includes the Glossary module, it will expand the definition of &quot;myterm&quot;.
<h4>Expanding Lists</h4>
<p>Sometimes, you will want a short list of terms, but have clicks on those terms to load a full list. For example, you might want three random terms in the sidebar, but clicking on those terms should show the selected term in a complete term list. To do this, set the &quot;no_pass_restriction&quot; variable.</p>
<p>For example, on your sidebar you want three random terms from category &quot;foo&quot;. Clicking on a term should show a full, alphabetical list of category &quot;foo&quot; with the specific term open. Your tag for the sidebar will then look like:</p>
<p>&amp;#123;cms_module module=&#039;Glossary&#039; cat=&#039;foo&#039; sort=&#039;random&#039; term_count=&#039;3&#039; no_pass_restriction=&#039;sort,term_count&#039;}</p>
<h4>WYSIWYG/Smarty</h4>
<p>In the admin, you can enable the WYSIWYG editor for terms and term definitions. Because of the way the system uses terms, it is not recommended
to use markup in the terms themselves. If you insist on doing it (and some people do, in fact, have good reasons to do so), be aware that site filtering will probably break, and the glossary page nav may be messed up.</p>
<p>You can also enable smarty processing on term definitions. This will permit you to do all sorts of wild stuff like self-linking and other smarty madness. Hey -- if you know enough to go on the black diamond run, you know the risks! I will say no more.</p>
<h3>Linked Terms</h3>
<h4>Overview</h4>
<p>You can make terms that show up in your pages link to their definitions, either &quot;inline&quot; (where it replaces the content of your page), or by linking to your main Glossary page. This is the &quot;inline&quot; option which you can set in the &quot;Glossary Links Options&quot; section of the Glossary Admin Prefs.</p>
<p>You can also choose to have links go to a page with only the definition of your term, and you can control the display of this by altering the template. This also set in &quot;Glossary Links Options&quot; section of the Glossary Admin Prefs.</p> 
<h4>Single Term</h4>
<p>You can tag specific words to be linked to the Glossary if you want, by placing the following tag in a page: &amp;#123;cms_module module=&#039;Glossary&#039; action=&#039;def&#039; term=&#039;foo&#039;}, where you replace &quot;foo&quot; with a term that you have in your glossary.
<h4>Term Replacement / Site Filtering</h4>
<p>If you turn on site filtering, every instance of each of your terms that shows up on the site will become a link. Depending on the mode you choose in the admin,
this will either be a link to your main Glossary page or open to the term in question.</p>
<p>Site filtering is an intensive process, and will slow your site down somewhat. There is an alternate, faster implementation that I may use to replace the existing one,
if there are enough complaints. It&#039;s more complicated, and I&#039;m lazy, but given sufficient demand, I&#039;ll fix it.</p>
<h3>Credits</h3>
<p>Development of this module has been generously sponsored by Matt Hornsby.</p>
<p>Extensive testing, QA, ideas, and non-negotiable demands provided by Paul &quot;InSiPiD&quot; Noone and Daniel &quot;Westis&quot; Westergren.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the
module homepage at <a href="http://dev.cmsmadesimple.org/projects/glossary/">the CMS Developer Forge</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, SjG, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2006, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com">&amp;lt;sjg@cmsmodules.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utma'] = '156861353.179052623084110100.1210423577.1232744717.1232748666.845';
$lang['utmz'] = '156861353.1232225861.833.24.utmccn=(referral)|utmcsr=petrache.biz|utmcct=/admin/siteprefs.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> Glossary-1.0.tar.gz: Glossary/lang/ext/nb_NO.php <==
<?php
$lang['areyousure_altercontent'] = 'Er du sikker p&aring; at du vil utf&oslash;re denne handlingen?  &Aring; fortsette vil permanent endre ditt innhold';
$lang['filter_site_now'] = 'Filtrer n&aring;';
$lang['friendlyname'] = 'Ordliste / Ordbok';
$lang['postinstall'] = '<p>Husk &aring; sette &quot;Modify Glossary&quot; tillatelser for &aring; bruke denne modulen!</p>
<p>Du vil sikkert ogs&aring; g&aring; inn og endre verdier ogs&aring;. Jeg har satt spesielle verdier for &aring; demonstrere muligheter. Men du vil f.eks. sikkert &oslash;nske mer enn fem uttrykk p&aring; en side,
og du vil &oslash;nske &aring; slette mine eksempel uttrykk og kategorier.';
$lang['postuninstall'] = 'Ble fjernet.';
$lang['uninstalled'] = 'Modul avinstallert.';
$lang['installed'] = 'Modul versjon %s installert.';
$lang['prefsupdated'] = 'Modul innstillinger oppdatert.';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk dine rettigheter.';
$lang['error'] = 'Feil!';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['title_mod_prefs'] = 'Modul innstillinger';
$lang['title_mod_admin'] = 'Modul administrasjonspanel';
$lang['title_term'] = 'Uttrykk';
$lang['title_tip'] = 'Boble / Lenke tittel for uttrykk';
$lang['title_definition'] = 'Definisjon';
$lang['column_definition'] = 'Definisjon';
$lang['title_default_template'] = 'Standard visnings mal';
$lang['title_default_single_term_template'] = 'Standard visnings mal for sprettopp vindu';
$lang['title_filter_site'] = 'Filtrer nettsted for uttrykk?';
$lang['title_filter_news'] = 'Filtrer Nyhetersartikler for uttrykk?';
$lang['title_number_show'] = 'Antall uttrykk &aring; vise pr side';
$lang['title_default_number_show'] = 'Standard antall uttrykk &aring; vise pr side';
$lang['title_filter_site_label'] = 'Aktiver alle uttrykk p&aring; nettstedet? (advarsel - bremser nettstedet)';
$lang['title_glossary_page'] = 'Ordliste side (m&aring;l for aktive lenker)';
$lang['title_disable_prettyurls'] = 'Koble ut vakre nettadresser for denne modulen';
$lang['title_disable_prettyurls_label'] = 'Koble ut';
$lang['title_glossary_inline'] = 'Vise linkede uttrykk inline?';
$lang['title_show_termids'] = 'Vis Uttrykk ID-nummere i admin';
$lang['title_display_tab'] = 'Ordliste visningsvalg';
$lang['title_single_term'] = 'Vise linkede uttrykk p&aring; egen side?';
$lang['title_single_term_label'] = 'Vise enkle uttrykk (i motsetning til full ordbok)';
$lang['title_wysiwyg_definitions'] = 'Benytt WYSIWYG for &aring; skrive uttrykksdefinisjoner?';
$lang['title_wysiwyg_terms'] = 'Benytt WYSIWYG for &aring; skrive uttrykk?';
$lang['title_wysiwyg_terms_help'] = 'Vennligst v&aelig;r oppmerksom p&aring; at markup inne i utrykk kan p&aring;virke bokstavinndeling(aphabetizing) og med aktiverte uttrykk!';
$lang['title_link_tab'] = 'Ordbok Link valg';
$lang['title_admin_tab'] = 'Administrasjonspanel valg';
$lang['title_filtering_tab'] = 'Nettsted Uttrykk-filtreringsvalg';
$lang['title_number_spining_chars'] = 'Maksimum antall bokstaver &aring; bruke av et uttrykk i Ordbok lenken';
$lang['title_process_smarty'] = 'Prosesser Smartytagger i definisjoner?';
$lang['filter_link'] = 'Link til Ordbok siden';
$lang['column_term'] = 'Uttrykk';
$lang['column_termid'] = 'Uttrykk ID';
$lang['column_action'] = 'Handling';
$lang['column_select'] = 'Velg';
$lang['column_category'] = 'Kategori';
$lang['title_admin_panel'] = 'Ordliste / Ordbok / (FAQ)';
$lang['title_term_list'] = 'Uttrykk';
$lang['title_name'] = 'Navn';
$lang['title_cats'] = 'Kategorier';
$lang['title_filter_category'] = 'Vis kun denne kategorien:';
$lang['title_all'] = 'Alle kategorier';
$lang['column_template'] = 'Mal navn';
$lang['title_template'] = 'Mal definisjon';
$lang['addterm'] = 'Legg til nytt Uttrykk';
$lang['termadded'] = 'Uttrykk ble lagt til.';
$lang['termdeleted'] = 'Uttrykk ble slettet.';
$lang['edit'] = 'Rediger uttrykk';
$lang['no'] = 'Nei';
$lang['yes'] = 'Ja';
$lang['filter'] = 'Filtrer';
$lang['delete'] = 'Slett uttrykk';
$lang['delete_selected'] = 'Slett valgte uttrykk';
$lang['areyousure_deletemultiple'] = 'Er du sikker p&aring; at du vil slette alle disse uttrykkene?';
$lang['suredelete'] = 'Er du sikker p&aring; at du vil slette uttrykket %s?';
$lang['listterms'] = 'Behandle uttrykk';
$lang['listtempl'] = 'Behandle maler';
$lang['listcats'] = 'Behandle kategorier';
$lang['addcat'] = 'Legg til kategori';
$lang['editcat'] = 'Rediger kategori';
$lang['delcat'] = 'Slett kategori';
$lang['manageprefs'] = 'Admin innstillinger';
$lang['templatelist'] = 'Maler';
$lang['unknown_term'] = 'Ukjent uttrykk %s forespurt.';
$lang['glossary_page_help'] = 'Velg en side her som inneholder en tagg for &aring; vise ordbok informasjonen, f.eks., en side som inneholder {cms_module module=&quot;Glossary&quot;}';
$lang['glossary_prettyurls_help'] = '&Aring; koble ut vakre nettadresser for denne modulen kan hjelpe i tilfeller hvor noen av s&oslash;keuttrykkene har ikke-alfanummeriske tegn eller mellomrom.';
$lang['glossary_inline_help'] = 'Bruk f&oslash;lgende valg om du &oslash;nsker at dine aktive-uttrykk definisjoner skal vises in-line. Dette er gjensidig eksklusivt for linking til Ordbok siden.';
$lang['title_glossary_inline_label'] = 'Vis inline';
$lang['notemplates'] = 'Ingen maler i databasen.';
$lang['nocats'] = 'Ingen kategorier i databasen.';
$lang['addtemplate'] = 'Legg til mal';
$lang['templateupdated'] = 'Mal oppdatert';
$lang['templatedeleted'] = 'Mal slettet';
$lang['catupdated'] = 'Kategori oppdatert';
$lang['catdeleted'] = 'Kategori slettet';
$lang['areyousure'] = 'Er du sikker p&aring; du vil slette %s?';
$lang['next'] = ' : Neste &raquo;';
$lang['prev'] = '&laquo; Forrige : ';
$lang['moddescription'] = 'Denne modulen tillater deg &aring; lage en liste med uttrykk og definisjoner &aring; vise frem. Et uttrykk kan v&aelig;re et ord, et ofte spurt sp&oslash;rsm&aring;l eller noe lignende.';
$lang['help_glossary_single'] = 'Vis et uttrykk';
$lang['help_glossary_tid'] = 'Term ID (UttrykksID) &aring; utheve/fremheve';
$lang['help_glossary_catid'] = 'Begrens listen til uttrykk i kategori ID &quot;catid&quot;';
$lang['help_glossary_start'] = 'Innrykk i liste for &aring; starte listing av uttrykk';
$lang['help_glossary_term'] = 'Uttrykk &aring; utheve/fremheve';
$lang['help_glossary_cat'] = 'Begrens listen til uttrykk i kategorien &quot;cat&quot;';
$lang['help_glossary_template'] = 'Malnavn eller ID &aring; benytte for &aring; formatere uttrykk';
$lang['help_glossary_term_count'] = 'Antall uttrykk som skal vises p&aring; en side (overstyrer standardinnstilling i admin)';
$lang['help_glossary_show_nav'] = 'Sett til 0 for &aring; skjule sideinndelings menyen';
$lang['help_glossary_keyword'] = 'Begrens til de uttrykk hvor definisjonen inneholder &quot;keyword&quot;';
$lang['help_glossary_sort'] = 'Sorteringsrekkef&oslash;lge: n&aring; st&oslash;ttes kun &quot;alpha&quot; eller &quot;random&quot;';
$lang['help_glossary_no_pass_restrictions'] = 'For &aring; vise en filtrert eller p&aring; annen m&aring;te begrenset liste, men &aring; f&aring;r &aring; ikke ha den utvidede listen begrenset, list feltene her (se eksemplet ovenfor)';
$lang['help_glossary_target'] = 'Side alias &aring; vise til for &aring; vise uttrykk';
?>
